@@ -19,3 +19,14 @@ class MoveDepartmentIndexForms(forms.Form):
     department_id = forms.IntegerField()
     type = forms.CharField(min_length=2, max_length=4)
 
+
+class RoleForms(forms.Form):
+    name = forms.CharField(min_length=2, max_length=50)
+    organization_id = forms.IntegerField()
+    desc = forms.CharField(required=False)
+
+
+class PositionForms(forms.Form):
+    name = forms.CharField(min_length=2, max_length=50)
+    organization_id = forms.IntegerField()
+    desc = forms.CharField(required=False)
